/*
 *		ISRlogic.inc
 *			An include file to the ChronosMEGA.asm
 *
 *		Function:
 *		Mostly handles the button input interrupts for the four buttons
 *		This is designed to only work on the ATmega328P, other chips may vary. 
 *
 *  Created: 3/13/2014 9:47:22 PM
 *  Developer: Nick Williams
*/

.cseg
.org 0x0300

Button1or2logic:
	RCALL	delay20ms_setup	;RCALL to function that will delay for 20ms to debounce buttons
	;nop					;temperary, should remove later. keep just in case for now
	in		r16, PIND		;load r16 with PIND
	SBRS	r16, 1			;Skip next instruction if Sleep is set (not pressed)
	rjmp	Button2logic	;jmp to the Button3logic if Sleep has been pressed
	SBRS	r16, 2			;Skip next instruction if Disp is set (not pressed)
	rjmp	Button1logic	;jmp to the Button4logic if Disp has been pressed
	ret					


;Sleep and Disp buttons
Button3or4logic:
	RCALL	delay20ms_setup	;RCALL to function that will delay for 20ms to debounce buttons
	;nop					;temperary, should remove later. keep just in case for now
	in		r16, PINC		;load r16 with PORTC
	SBRS	r16, 5			;Skip next instruction if Sleep is set (not pressed)
	rjmp	Button3logic	;jmp to the Button3logic if Sleep has been pressed
	SBRS	r16, 4			;Skip next instruction if Disp is set (not pressed)
	rjmp	Button4logic	;jmp to the Button4logic if Disp has been pressed
	ret					

Button1logic:
	RCALL	DispTime
	RCALL	IncMin
	ret

Button2logic:
	lds		r16, MIN
	push	r16
	RCALL	DispTime
	RCALL	IncHr
	pop		r16
	sts		MIN, r16
	ret

Button3logic:
	lds		r16, slpBool
	ldi		r17, 0x01
	eor		r16, r17
	sts		slpBool, r16
	RCALL	MapLEDs
	ret

Button4logic:
	rjmp	DispTime

DispTime:
	ldi		r16, 0x01
	sts		dispBool, r16
	ldi		r16, 0x00
	sts		TCNT1H, r16
	sts		TCNT1L, r16
	ldi		r16, 0x02
	sts		TIMSK1, r16
	ret

delay20ms_setup:
	push	r16			;put r16 onto the stack
	ldi r16, 0xFF

delay20ms:
	nop					;each nop is one clock cycle
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop					
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop					
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	nop
	dec	r16
	breq	delay20ms_done		;end if the counter is finished
	rjmp	delay20ms	;loop back 

delay20ms_done:
	pop		r16			;give r16 its original value
	ret