/*
 *		TimeLogic.inc
 *			An include file to the ChronosMEGA.asm
 *
 *		Function:
 *		Handles Time logic to change time variables when necessary 
 *
 *  Created: 3/13/2014 9:47:22 PM
 *  Developer: Nick Williams
*/

.cseg
.org 0x0100

;IncSec10:
;Increment the 1/10 of a second value and store in SRAM
;If SEC10 is equal to 10, increment the second value
IncSec10:

	clz							;clear the Z flag
	lds		r16, SEC10			;load the SEC10 value
	inc		r16					;increment
	sts		SEC10, r16			;store back
	cpi		r16, 0x0A			;compare SEC10 val with 10
	breq	IncSec				;if equal, branch to IncSec
	clz							;if not, compare to 9
	cpi		r16, 0x09			;compare SEC10 val with 9
	breq	ChangeOCR2A			;lengthen the OCR2A reg just a little bit to make an exact second
	ret


;ChangeOCR2A:
;since 32,768 Hz cannot be divided by 10 evenly, the last 10th of a second
;needs to be a little shorter than the rest to make an exact second
;Originally OCR2A is 12, here it is 10
ChangeOCR2A:
	ldi		r16, 0x0A			;load 10 into r16
	sts		OCR2A, r16			;set OCR2A to 105
	ret

IncSec:
	clz
	ldi		r16, 0x0C			;load r16 with 101
	sts		OCR2A, r16			;set OCR2A back to 101
	ldi		r16, 0x00			;reset SEC10 to 0
	sts		SEC10, r16			;Store to SRAM
	lds		r16, SECND			;load SECND var
	inc		r16					;increment SECND
	sts		SECND, r16			;store new SECND value back to SRAM
	cpi		r16, 0x3C			;Compare SECND to 60
	breq	IncMin				;if equal, increment the minutes
	ret

;IncMin:
;Increment the minutes value, if MIN==60, then increment the HR
IncMin:
	clz
	ldi		r16, 0x00			;Reset the SECND to 0
	sts		SECND, r16			
	lds		r16, MIN			;Load the minutes
	inc		r16					;increment MIN
	sts		MIN, r16			;Store the incremented MIN value into SRAM 
	cpi		r16, 0x3C			;Compare to 60
	breq	IncHr				;if equal, increment the hours
	ret

;IncHr:
;Increment the hours value, if HR==13, then reset the HR back to 1
IncHr:
	clz
	ldi		r16, 0x00
	sts		MIN, r16			;Reset MIN to 0
	lds		r16, HR				;Load the Hour
	inc		r16					;increment the Hours value
	sts		HR, r16				;Store the incremented HR value into SRAM
	cpi		r16, 0x0D			;compare HR to 13
	breq	RstHr				;Reset the Hours if equal to 13
	ret

;RstHr:
;Reset the Hr var back to 1 if it reaches 13
RstHr:
	ldi		r16, 0x01
	sts		HR, r16				;Store 1 into the HR val in SRAM
	ret